import { Injectable } from '@nestjs/common';
import { InjectRepository } from '@nestjs/typeorm';
import { Business } from 'src/business/entities/business.entity';
import { BusinessStatus, MemberStatus, YNStatus } from 'src/enum';
import { Licence } from 'src/licence/entities/licence.entity';
import { MembershipCard } from 'src/membership-card/entities/membership-card.entity';
import { UserDetail } from 'src/user-details/entities/user-detail.entity';
import { Repository } from 'typeorm';

@Injectable()
export class DashboardService {
  constructor(
    @InjectRepository(Business)
    private readonly businessRepo: Repository<Business>,
    @InjectRepository(Licence)
    private readonly licenceRepo: Repository<Licence>,
    @InjectRepository(UserDetail)
    private readonly udRepo: Repository<UserDetail>,
    @InjectRepository(MembershipCard)
    private readonly mCardRepo: Repository<MembershipCard>,
  ) {}

  async businessCount() {
    const activeBusiness = await this.businessRepo.count({
      where: { status: BusinessStatus.ACTIVE },
    });

    const renewalBusiness = await this.businessRepo.count({
      where: { status: BusinessStatus.RENEWAL },
    });

    const expiredBusiness = await this.businessRepo.count({
      where: { status: BusinessStatus.EXPERIED },
    });

    return {
      activeBusiness: activeBusiness,
      renewalBusiness: renewalBusiness,
      expiredBusiness: expiredBusiness,
    };
  }

  async amcUsers() {
    const result = await this.licenceRepo.count({
      where: { amc: YNStatus.YES },
    });

    return { amcUser: result };
  }

  async getCount(accountId: string) {
    const memberCount = await this.udRepo.count({
      where: { createdById: accountId },
    });

    const activeMember = await this.udRepo.count({
      where: { createdById: accountId, status: MemberStatus.ACTIVE },
    });

    const cardCount = await this.mCardRepo.count({ where: { accountId } });

    return {
      memberCount: memberCount,
      activeMembership: activeMember,
      cardCount: cardCount,
    };
  }
}
